==> 4.0.0-ISS-GKLM-FP0005-AIX.tar.gz: bin/db/nonrootconfig.sh <==
#!/bin/sh
#set -x
# Licensed Materials-Property of IBM
# (C)Copyright IBM Corp 2008
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
# 
# The script is to be called from the IBM Security Key Life Cycle Manager 
# Installer
# arg1 -  dbinstance_owner_home - (For example /home/db2inst2)
# arg2 -  instance  -  instance name (for example db2inst2) 
# arg3 -  dbport - - database port 
# arg4 -  db_user - - database user
# arg5 -  db_password - - database password
# arg6 -  was_home - - WAS HOME path
# arg7 -  was_admin_user - - WAS admin user name
# arg8 -  was_admin_password - - WAS admin password
#------------------------------------------------------------------------------

DB_INST_HOME=$1
DB_INST_NAME=$2
PORT=$3
DB_USER=$4
DB_PASSWORD=$5
WAS_HOME=$6
WAS_USER=$7
WAS_PSWD=$8
if [ $# -ne 8 ]
then
echo Usage: nonrootconfig.sh DB_INST_HOME DB_INST_NAME PORT DB_USER DB_PASSWORD WAS_HOME WAS_USER WAS_PASSWORD
    exit 2
fi
sudo sed -i 's/ENABLE_OS_AUTHENTICATION=NO/ENABLE_OS_AUTHENTICATION=YES/' $DB_INST_HOME/sqllib/instance/db2rfe.cfg
sudo $DB_INST_HOME/sqllib/instance/db2rfe -f $DB_INST_HOME/sqllib/instance/db2rfe.cfg > /tmp/nonroot_install.log
su - $DB_USER -c "$DB_INST_HOME/sqllib/adm/db2set db2comm=tcpip" >> /tmp/nonroot_install.log
su - $DB_USER -c "$DB_INST_HOME/sqllib/adm/db2start" >> /tmp/nonroot_install.log
su - $DB_USER -c "$DB_INST_HOME/sqllib/bin/db2 -tvf $DB_INST_HOME/nonrootqry.sql" >> /tmp/nonroot_install.log
rc=$?
if [ $rc -eq 0 ]
then
	sudo echo db2c_$DB_INST_NAME	$PORT/tcp >> /etc/services
	rc=$?
fi
if [ $rc -eq 0 ]
then
	su - $DB_USER -c "$DB_INST_HOME/sqllib/adm/db2stop force" >> /tmp/nonroot_install.log
	su - $DB_USER -c "$DB_INST_HOME/sqllib/adm/db2start" >> /tmp/nonroot_install.log
	echo non-root DB2 configuration successful.
else
	echo non-root DB2 configuration failed, please try again after validating input parameters and user credentials. 
fi

chmod +x -R  ${WAS_HOME}/bin/*.*
sh ${WAS_HOME}/bin/wasservice.sh  -remove SecurityKeyLifecycleManager40  >> /tmp/nonroot_install.log
#echo sh ${WAS_HOME}/bin/wasservice.sh  -add SecurityKeyLifecycleManager40 -serverName server1 -profilePath "${WAS_HOME}/profiles/KLMProfile" -logRoot "${WAS_HOME}/profiles/KLMProfile/logs/server1" -startType automatic -restart true -encodeParams -stopArgs "-username ${WAS_USER} -password ${WAS_PSWD}" -userid ${DB_USER} -password ${DB_PASSWORD}
sh ${WAS_HOME}/bin/wasservice.sh  -add SecurityKeyLifecycleManager40 -serverName server1 -profilePath "${WAS_HOME}/profiles/KLMProfile" -logRoot "${WAS_HOME}/profiles/KLMProfile/logs/server1" -startType automatic -restart true -encodeParams -stopArgs "-username ${WAS_USER} -password ${WAS_PSWD}" -userid ${DB_USER} -password ${DB_PASSWORD}
chmod 755 -R  ${WAS_HOME}/bin/*.*

. ${WAS_HOME}/properties/sklm.properties
sh $DB_INST_HOME/sklm40properties/scripts/sklmservice.sh "db2c_$DB_INST_NAME.service" "$DB_INST_HOME" "$DB_USER" "$DB_INST_NAME" "$WAS_HOME" "sklm40properties" "${SKLM_INSTALL_DIR}"
rc=$?
exit $rc

==> 4.1.0-ISS-GKLM-FP0005-AIX.tar.gz: bin/db/nonrootconfig.sh <==
#!/bin/sh
#set -x
# Licensed Materials-Property of IBM
# (C)Copyright IBM Corp 2008
# All rights reserved
# US Government Users Restricted Rights
# Use, duplication, or disclosure restricted
# by GSA ADP Schedule Contract with IBM Corp
# 
# The script is to be called from the IBM Security Guardium Key Life Cycle Manager 
# Installer
# arg1 -  dbinstance_owner_home - (For example /home/db2inst2)
# arg2 -  instance  -  instance name (for example db2inst2) 
# arg3 -  dbport - - database port 
# arg4 -  db_user - - database user
# arg5 -  db_password - - database password
# arg6 -  was_home - - WAS HOME path
# arg7 -  was_admin_user - - WAS admin user name
# arg8 -  was_admin_password - - WAS admin password
#------------------------------------------------------------------------------

DB_INST_HOME=$1
DB_INST_NAME=$2
PORT=$3
DB_USER=$4
DB_PASSWORD=$5
WAS_HOME=$6
WAS_USER=$7
WAS_PSWD=$8
if [ $# -ne 8 ]
then
echo Usage: nonrootconfig.sh DB_INST_HOME DB_INST_NAME PORT DB_USER DB_PASSWORD WAS_HOME WAS_USER WAS_PASSWORD
    exit 2
fi
sudo sed -i 's/ENABLE_OS_AUTHENTICATION=NO/ENABLE_OS_AUTHENTICATION=YES/' $DB_INST_HOME/sqllib/instance/db2rfe.cfg
sudo $DB_INST_HOME/sqllib/instance/db2rfe -f $DB_INST_HOME/sqllib/instance/db2rfe.cfg > /tmp/nonroot_install.log
su - $DB_USER -c "$DB_INST_HOME/sqllib/adm/db2set db2comm=tcpip" >> /tmp/nonroot_install.log
su - $DB_USER -c "$DB_INST_HOME/sqllib/adm/db2start" >> /tmp/nonroot_install.log
su - $DB_USER -c "$DB_INST_HOME/sqllib/bin/db2 -tvf $DB_INST_HOME/nonrootqry.sql" >> /tmp/nonroot_install.log
rc=$?
if [ $rc -eq 0 ]
then
	sudo echo db2c_$DB_INST_NAME	$PORT/tcp >> /etc/services
	rc=$?
fi

if [ $rc -eq 0 ]
then
	su - $DB_USER -c "$DB_INST_HOME/sqllib/adm/db2stop force" >> /tmp/nonroot_install.log
	su - $DB_USER -c "$DB_INST_HOME/sqllib/adm/db2start" >> /tmp/nonroot_install.log
	echo non-root DB2 configuration successful.
else
	echo non-root DB2 configuration failed, please try again after validating input parameters and user credentials. 
fi

chmod +x -R  ${WAS_HOME}/bin/*.*
echo Try removing service SecurityKeyLifecycleManager41, if exist.  >> /tmp/nonroot_install.log
sh ${WAS_HOME}/bin/wasservice.sh  -remove SecurityKeyLifecycleManager41  >> /tmp/nonroot_install.log
#echo sh ${WAS_HOME}/bin/wasservice.sh  -add SecurityKeyLifecycleManager41 -serverName server1 -profilePath "${WAS_HOME}/profiles/KLMProfile" -logRoot "${WAS_HOME}/profiles/KLMProfile/logs/server1" -startType automatic -restart true -encodeParams -stopArgs "-username ${WAS_USER} -password ${WAS_PSWD}" -userid ${DB_USER} -password ${DB_PASSWORD}
sh ${WAS_HOME}/bin/wasservice.sh  -add SecurityKeyLifecycleManager41 -serverName server1 -profilePath "${WAS_HOME}/profiles/KLMProfile" -logRoot "${WAS_HOME}/profiles/KLMProfile/logs/server1" -startType automatic -restart true -encodeParams -stopArgs "-username ${WAS_USER} -password ${WAS_PSWD}" -userid ${DB_USER} -password ${DB_PASSWORD}
chmod 755 -R  ${WAS_HOME}/bin/*.*

. ${WAS_HOME}/properties/sklm.properties
sh $DB_INST_HOME/sklm41properties/scripts/sklmservice.sh "db2c_$DB_INST_NAME.service" "$DB_INST_HOME" "$DB_USER" "$DB_INST_NAME" "$WAS_HOME" "sklm41properties" "${SKLM_INSTALL_DIR}"
rc=$?
exit $rc
